# Changelog

All notable changes to this project will be documented in this file.

## [0.1.14] - 2025-04-01

## [0.1.13] - 2025-04-01

## [0.1.12] - 2025-04-01

## [0.1.11] - 2025-04-01

## [0.1.10] - 2025-04-01

### Added
- Changes in increment_project.py

## [0.1.9] - 2025-04-01

### Removed
- Changes in out/secure_credentials/.gitignore
- Changes in out/secure_credentials/README.md
- Changes in out/secure_credentials/credentials_metadata.yaml
- Changes in out/secure_credentials/examples/__init__.py
- Changes in out/secure_credentials/examples/aws_login.py
- Changes in out/secure_credentials/examples/stripe_login.py
- Changes in out/secure_credentials/pyproject.toml
- Changes in out/secure_credentials/requirements.txt
- Changes in out/secure_credentials/src/__init__.py
- Changes in out/secure_credentials/src/automation/__init__.py
- Changes in out/secure_credentials/src/automation/browser.py
- Changes in out/secure_credentials/src/automation/login_automator.py
- Changes in out/secure_credentials/src/automation/session_manager.py
- Changes in out/secure_credentials/src/core/__init__.py
- Changes in out/secure_credentials/src/core/credentials_manager.py
- Changes in out/secure_credentials/src/core/encryption.py
- Changes in out/secure_credentials/src/core/rotator.py
- Changes in out/secure_credentials/src/core/validators.py
- Changes in out/secure_credentials/src/providers/__init__.py
- Changes in out/secure_credentials/src/providers/base.py
- Changes in out/secure_credentials/src/providers/bitwarden_provider.py
- Changes in out/secure_credentials/src/providers/env_provider.py
- Changes in out/secure_credentials/src/providers/firefox_provider.py
- Changes in out/secure_credentials/src/providers/keepass_provider.py
- Changes in out/secure_credentials/src/providers/keyring_provider.py
- Changes in out/secure_credentials/src/utils/__init__.py
- Changes in out/secure_credentials/src/utils/logger.py
- Changes in out/secure_credentials/src/utils/security.py
- Changes in out/secure_credentials/tests/__init__.py
- Changes in out/secure_credentials/tests/test_automation.py
- Changes in out/secure_credentials/tests/test_credentials_manager.py
- Changes in out/secure_credentials/tests/test_providers.py
- Changes in src/mdirtree/__init__.py.bak

## [0.1.8] - 2025-04-01

## [0.1.7] - 2025-04-01

## [0.1.6] - 2025-04-01

### Added
- Changes in structure2.md

## [0.1.5] - 2025-04-01

### Added
- Changes in increment_init.py
- Changes in increment_setup.py
- Changes in increment_version.py
- Changes in project.sh
- Changes in upgrade.sh

## [0.1.4] - 2025-03-31

## [0.1.3] - 2025-03-31

## [0.1.2] - 2025-03-31

## [0.1.1] - 2025-03-31

### Removed
- Changes in desired_output_directory/.gitignore
- Changes in desired_output_directory/README.md
- Changes in desired_output_directory/credentials_metadata.yaml
- Changes in desired_output_directory/examples/__init__.py
- Changes in desired_output_directory/examples/aws_login.py
- Changes in desired_output_directory/examples/stripe_login.py
- Changes in desired_output_directory/pyproject.toml
- Changes in desired_output_directory/requirements.txt

## [0.1.0] - 2025-03-31

### Removed
- Changes in os
- Changes in re
- Changes in subprocess

## [0.1.2] - 2024-11-24

### Fixed
- issues with deployment and publishing


## [0.1.1] - 2024-11-24

### Fixed
- issues with deployment and publishing

## [0.1.0] - 2024-11-24

### Added
- Changes in .pre-commit-config.yaml
- Changes in CHANGELOG.md
- Changes in CONTRIBUTION.md
- Changes in changelog.py
- Changes in git.sh
- Changes in init.sh
- Changes in publish.sh
- Changes in pyproject.toml
- Changes in requirements-dev.txt
- Changes in requirements.txt
- Changes in setup.cfg
- Changes in setup.py
- Changes in src/mdirtree/__init__.py
- Changes in src/mdirtree/_version.py
- Changes in src/mdirtree/cli.py
- Changes in src/mdirtree/examples/rest_examples.py
- Changes in src/mdirtree/generator.py
- Changes in src/mdirtree/rest/client.py
- Changes in src/mdirtree/rest/server.py
- Changes in start.sh
- Changes in structure.md
- Changes in tests/test_generator.py
- Changes in tests/test_rest.py
- Changes in tox.ini
- Changes in version.sh

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

